* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [User and Access Management](https://help.sap.com/docs/leanix/ea/user-and-access-management)
  * Single Sign-On (SSO)
